==> haskell-wai-app-file-cgi-3.1.11-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-file-cgi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-file-cgi
version:              3.1.11
visibility:           public
id:                   wai-app-file-cgi-3.1.11-6fy7QPjSUWqC1L8bFUHii7
key:                  wai-app-file-cgi-3.1.11-6fy7QPjSUWqC1L8bFUHii7
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/mighttpd/
synopsis:             File/CGI/Rev Proxy App of WAI
description:
    This WAI application library handles static files,
    executes CGI scripts, and serves as a reverse proxy
    (including EventSource).

category:             Web, Yesod
abi:                  e552f1cb609eccc7d721bee20115c813
exposed:              True
exposed-modules:      Network.Wai.Application.Classic
hidden-modules:
    Network.Wai.Application.Classic.CGI
    Network.Wai.Application.Classic.Conduit
    Network.Wai.Application.Classic.Def
    Network.Wai.Application.Classic.EventSource
    Network.Wai.Application.Classic.Field
    Network.Wai.Application.Classic.File
    Network.Wai.Application.Classic.FileInfo
    Network.Wai.Application.Classic.Header
    Network.Wai.Application.Classic.Lang
    Network.Wai.Application.Classic.Path
    Network.Wai.Application.Classic.Redirect
    Network.Wai.Application.Classic.Status
    Network.Wai.Application.Classic.Types
    Network.Wai.Application.Classic.RevProxy

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-file-cgi
hs-libraries:         HSwai-app-file-cgi-3.1.11-6fy7QPjSUWqC1L8bFUHii7
depends:
    array-0.5.6.0 attoparsec-0.14.4-ARFIPKVHAQdH6rZ1P31wQY
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-26iNgmqHMOsJk4yniKxDB2
    conduit-1.3.6.1-9Ano6zkKE8Q3t2Yg7Ibwss
    conduit-extra-1.3.8-B6Eb1ypzIORHRjCExezdNC containers-0.6.7
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc directory-1.3.8.5
    filepath-1.4.300.1 http-client-0.7.19-3gG1vVFkVnQK6P9M9ZTkXM
    http-conduit-2.3.9.1-K1rBhxqbn2TXotaq4g8MV
    http-date-0.0.11-BDrsSmoQgTy93ipYwT57nM
    http-types-0.12.4-DpLRlhCeIkXGgeQrwJBKkM
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    network-3.1.4.0-Kxe15bkS84aBmhotDoAJWo process-1.6.19.0
    sockaddr-0.0.1-EdJMzTwaAdXIDANQgkvI2D
    static-hash-0.0.2-IIywkpoRq8dJZXaMCBXQsR text-2.0.2
    transformers-0.6.1.0 unix-2.8.4.0 wai-3.2.4-DP7Wq107T9eHDgy7g2zCw
    wai-conduit-3.0.0.4-FH1TXP5jn8NFXUuGJj10iC
    warp-3.4.0-4jTdxXQfffMAWOOz9ZYhu4
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-file-cgi/html/wai-app-file-cgi.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-file-cgi/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-file-cgi-3.1.11-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-file-cgi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-file-cgi
version:              3.1.11
visibility:           public
id:                   wai-app-file-cgi-3.1.11-1Yk3NZWcV8C4GEhyxVPa0P
key:                  wai-app-file-cgi-3.1.11-1Yk3NZWcV8C4GEhyxVPa0P
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/mighttpd/
synopsis:             File/CGI/Rev Proxy App of WAI
description:
    This WAI application library handles static files,
    executes CGI scripts, and serves as a reverse proxy
    (including EventSource).

category:             Web, Yesod
abi:                  5573bbe9d197b56cfbb5ed51857028cd
exposed:              True
exposed-modules:      Network.Wai.Application.Classic
hidden-modules:
    Network.Wai.Application.Classic.CGI
    Network.Wai.Application.Classic.Conduit
    Network.Wai.Application.Classic.Def
    Network.Wai.Application.Classic.EventSource
    Network.Wai.Application.Classic.Field
    Network.Wai.Application.Classic.File
    Network.Wai.Application.Classic.FileInfo
    Network.Wai.Application.Classic.Header
    Network.Wai.Application.Classic.Lang
    Network.Wai.Application.Classic.Path
    Network.Wai.Application.Classic.Redirect
    Network.Wai.Application.Classic.Status
    Network.Wai.Application.Classic.Types
    Network.Wai.Application.Classic.RevProxy

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-app-file-cgi-3.1.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-file-cgi
hs-libraries:         HSwai-app-file-cgi-3.1.11-1Yk3NZWcV8C4GEhyxVPa0P
depends:
    array-0.5.6.0 attoparsec-0.14.4-K96akOPZKYDKXaMIGNQXgm
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-LnNRkIvaVf25YvATjz2MZ1
    conduit-1.3.6.1-JmvSlylEAqiI8LFhx2lxVp
    conduit-extra-1.3.8-GJ8Ijj1CXjtIz1f8rXkRx2 containers-0.6.7
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc directory-1.3.8.5
    filepath-1.4.300.1 http-client-0.7.19-B5USSZypF8s1UPWufciwbp
    http-conduit-2.3.9.1-5YDZP1W1TG7LHVkUDM627s
    http-date-0.0.11-6gmANqoCbBHG50HPgGzVhF
    http-types-0.12.4-Ab6499xPt6j7ocIybq2ygA
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART
    network-3.1.4.0-DqImTC0JtBs7wAjAQOfbw6 process-1.6.19.0
    sockaddr-0.0.1-EwvBMTc7ammFNn6tbYKUt6
    static-hash-0.0.2-78XpJ5D7LLpLHydKJv836g text-2.0.2
    transformers-0.6.1.0 unix-2.8.4.0 wai-3.2.4-L3dKuQqjqvcGg94VR3jCz4
    wai-conduit-3.0.0.4-8uijUrr8SJl71SCHy436qr
    warp-3.4.0-LPhizoV0zB3FM7W9iJLTSy
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-file-cgi/html/wai-app-file-cgi.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-file-cgi/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
